@@ -58,7 +58,12 @@ def check_and_update_analytics_config(ctx: click.Context, config_path: str) -> N
 
     if (
         ctx.obj["CONFIG"].user.analytics_opt_out is False
-        and get_config_from_file(config_path, "cli", "analytics_id") is None
+        and get_config_from_file(
+            config_path,
+            "cli",
+            "analytics_id",
+        )
+        in ("", None)
     ):
         config_updates.update(cli={"analytics_id": ctx.obj["CONFIG"].cli.analytics_id})
 
